@@ -6,7 +6,6 @@ from typing import NoReturn, Optional, Callable, List, Tuple, Set, Dict, Type, c
 from os import environ
 from signal import SIGTERM
 from socket import error as SocketError
-from datetime import datetime
 from math import ceil
 from operator import itemgetter
 
@@ -43,7 +42,9 @@ from .users.base import GrizzlyUser
 
 from .utils import create_scenario_class_type, create_user_class_type
 
-__all__: List[str] = []
+__all__: List[str] = [
+    'stats_logger',
+]
 
 
 unhandled_greenlet_exception = False
@@ -490,13 +491,6 @@ def run(context: Context) -> int:
                 print_error_report(runner.stats)
                 print_scenario_summary(grizzly)
 
-                # show start and stop date time
-                stopped = datetime.now()
-
-                print('')
-                print(f'Started: {context.started}')
-                print(f'Stopped: {stopped}')
-
             def spawning_complete() -> bool:
                 if isinstance(runner, MasterRunner):
                     return runner.spawning_completed
