@@ -57,15 +57,14 @@ And set response content type to "application/json"
 ```
 
 '''
-from typing import TYPE_CHECKING, List, Optional, Any, Callable
+from typing import TYPE_CHECKING, Dict, List, Optional, Any, Callable
 
 from jinja2.environment import Template
 from grizzly_extras.transformer import TransformerContentType
 from grizzly_extras.arguments import parse_arguments, split_value, unquote
 
-from ..types import RequestMethod
-# need to rename to avoid unused-import collision due to RequestTask.template ?!
-from . import GrizzlyTask, template  # pylint: disable=unused-import
+from ..types import GrizzlyResponse, RequestMethod
+from . import GrizzlyMetaRequestTask, template  # pylint: disable=unused-import
 
 if TYPE_CHECKING:  # pragma: no cover
     from ..context import GrizzlyContextScenario
@@ -90,7 +89,7 @@ class RequestTaskHandlers:
 
 class RequestTaskResponse:
     status_codes: List[int]
-    content_type: TransformerContentType
+    content_type: TransformerContentType  # @TODO remove this one!
     handlers: RequestTaskHandlers
 
     def __init__(self) -> None:
@@ -108,13 +107,15 @@ class RequestTaskResponse:
                 self.status_codes.pop(index)
 
 
-@template('name', 'endpoint', 'source')
-class RequestTask(GrizzlyTask):
+@template('name', 'endpoint', 'source', 'arguments', 'metadata')
+class RequestTask(GrizzlyMetaRequestTask):
     method: RequestMethod
     name: str
     endpoint: str
     _template: Optional[Template]
     _source: Optional[str]
+    arguments: Optional[Dict[str, str]]
+    metadata: Optional[Dict[str, str]]
 
     response: RequestTaskResponse
 
@@ -124,6 +125,8 @@ class RequestTask(GrizzlyTask):
         self.method = method
         self.name = name
         self.endpoint = endpoint
+        self.arguments = None
+        self.metadata = None
 
         self._template = None
         self._source = source
@@ -134,19 +137,20 @@ class RequestTask(GrizzlyTask):
 
         if '|' in self.endpoint:
             value, value_arguments = split_value(self.endpoint)
-            arguments = parse_arguments(value_arguments, unquote=False)
+            self.arguments = parse_arguments(value_arguments, unquote=True)
 
-            if 'content_type' in arguments:
-                content_type = TransformerContentType.from_string(unquote(arguments['content_type']))
-                del arguments['content_type']
+            if 'content_type' in self.arguments:
+                content_type = TransformerContentType.from_string(unquote(self.arguments['content_type']))
+                del self.arguments['content_type']
 
-            value_arguments = ', '.join([f'{key}={value}' for key, value in arguments.items()])
-            if len(value_arguments) > 0:
-                self.endpoint = f'{value} | {value_arguments}'
-            else:
-                self.endpoint = value
+                if content_type == TransformerContentType.MULTIPART_FORM_DATA and \
+                   ('multipart_form_data_name' not in self.arguments or 'multipart_form_data_filename' not in self.arguments):
+                    raise ValueError(f'Content type multipart/form-data requires endpoint arguments multipart_form_data_name and multipart_form_data_filename: {self.endpoint}')
+
+            self.endpoint = value
 
         self.response.content_type = content_type
+        self.content_type = content_type
 
     @property
     def source(self) -> Optional[str]:
@@ -167,8 +171,17 @@ class RequestTask(GrizzlyTask):
 
         return self._template
 
+    def add_metadata(self, key: str, value: str) -> None:
+        if self.metadata is None:
+            self.metadata = {key: value}
+        else:
+            self.metadata[key] = value
+
     def __call__(self) -> Callable[['GrizzlyScenario'], Any]:
         def task(parent: 'GrizzlyScenario') -> Any:
             return parent.user.request(self)
 
         return task
+
+    def execute(self, parent: 'GrizzlyScenario') -> GrizzlyResponse:
+        return parent.user.request(self)
