@@ -105,7 +105,7 @@ class SftpUser(ResponseHandler, RequestLogger, GrizzlyUser, FileRequests):
         self.sftp_client = SftpClientSession(host, port)
 
     def request(self, request: RequestTask) -> GrizzlyResponse:
-        request_name, endpoint, payload = self.render(request)
+        request_name, endpoint, payload, _, _ = self.render(request)
 
         name = f'{request.scenario.identifier} {request_name}'
 
