@@ -1,5 +1,5 @@
 from typing import Optional, Generator, Dict, cast
-from time import monotonic as time, sleep
+from time import perf_counter as time, sleep
 from contextlib import contextmanager
 
 from ...transformer import transformer, TransformerError, TransformerContentType
@@ -110,6 +110,8 @@ class AsyncMessageQueueHandler(AsyncMessageHandler):
         self.message_wait = context.get('message_wait', None) or 0
         self.header_type = context.get('header_type', None)
 
+        self.logger.info(f'connected to {connection}')
+
         return {
             'message': 'connected',
         }
@@ -257,20 +259,21 @@ class AsyncMessageQueueHandler(AsyncMessageHandler):
             with self.queue_context(endpoint=queue_name) as queue:
                 do_retry: bool = False
 
+                self.logger.info(f'executing {action} on {queue_name}')
+                start = time()
                 if action == 'PUT':
-                    payload = request.get('payload', None)
+                    request_payload = payload = request.get('payload', None)
                     if self.header_type:
                         if self.header_type == 'rfh2':
                             rfh2_encoder = Rfh2Encoder(payload=cast(str, payload).encode(), queue_name=queue_name, metadata=metadata)
-                            payload = rfh2_encoder.get_message()
+                            request_payload = rfh2_encoder.get_message()
                         else:
                             raise AsyncMessageError(f'Invalid header_type: {self.header_type}')
 
-                    response_length = len(payload) if payload is not None else 0
-                    queue.put(payload, md)
+                    response_length = len(request_payload) if request_payload is not None else 0
+                    queue.put(request_payload, md)
 
                 elif action == 'GET':
-
                     if msg_id_to_fetch is not None:
                         gmo = self._create_gmo()
                         gmo.MatchOptions = pymqi.CMQC.MQMO_MATCH_MSG_ID
@@ -294,12 +297,15 @@ class AsyncMessageQueueHandler(AsyncMessageHandler):
                             do_retry = True
                         else:
                             # Some other error condition.
+                            self.logger.error(str(e), exc_info=True)
                             raise AsyncMessageError(str(e))
 
                 if do_retry:
                     retries += 1
                     sleep(retries * retries * 0.5)
                 else:
+                    delta = (time() - start) * 1000
+                    self.logger.info(f'{action} on {queue_name} took {delta} ms, {response_length=}, {retries=}')
                     return {
                         'payload': payload,
                         'metadata': md.get(),
